@@ -46,18 +46,21 @@ class FeiShuPlugin(NotificationPlugin):
         """
         if not self.should_notify(group, event):
             return
-
         access_token = self.get_option('access_token', group.project)
         send_url = FeiShuTalk_API.format(token=access_token)
         project = event.group.project
-        title = event.title.encode("utf-8")
-        # title = u"New alert from {}".format(project.slug)
-        project_name = project.get_full_name().encode("utf-8")
+        title = event.title.encode("utf-8").decode("utf-8")
+        project_name = project.get_full_name().encode("utf-8").decode("utf-8")
+        body = b"Sentry [%s] %s: %s" % (
+            project.name.encode("utf-8"),
+            event.group.get_level_display().upper().encode("utf-8"),
+            event.title.encode("utf-8").splitlines()[0],
+        )
         data = {"title": title, "msg_type": "text",
-                "content": {"text": "#### {title} \n > {project_name};{message} [href]({url})".format(
+                "content": {"text": "{title} \n > {body}; \n[href]({url})".format(
                     title=title,
-                    message=event.message,
                     project_name=project_name,
+                    body=body,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )}}
         requests.post(
